@@ -24,17 +24,17 @@
     limitations under the License.
 """
 import sys
+import time
 import logging
 import argparse
 import fs
-import humanfriendly
+from fs.opener import parse
 from PyQt5 import QtWidgets, QtCore
 from PyQt5.QtWidgets import QAbstractItemView
 from PyQt5.QtGui import QIcon
 from fslib import ui_filepicker, __version__
-from fslib.utils import match_extension, WidgetImageText, WidgetText
+from fslib.utils import root_url, human_readable_info, match_extension, FOLDER_SPACES, FILES_SPACES, WidgetImage
 from fslib.icons import icons
-from fslib.utils import root_url
 
 
 class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
@@ -42,6 +42,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
                  default_filename=None, show_save_action=False):
         super(FilePicker, self).__init__(parent)
         self.setupUi(self)
+        self.setWindowIcon(QIcon(icons('fs_logo.png', origin='fs')))
         self.file_icon = icons('text-x-generic.png')
         self.dir_icon = icons('folder.png')
         self.selected_dir = None
@@ -52,6 +53,7 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.fs_home_url = u"~/"
         self.fs_root_url = root_url()
         self.active_url = self.fs_url
+        self.authentification = None
         self.parent_url = self.fs_url
         self.fs = None
         self.file_list_items = []
@@ -136,10 +138,16 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             self.wparm = None
         try:
             self.fs = fs.open_fs(self.active_url)
-        # ToDo lookup external library why it is not e.g. OpenFailed
-        except fs.errors.CreateFailed:
+        except IOError:
             logging.error(u"{} does not exist!".format(self.active_url))
             exit()
+        try:
+            parseresult = parse(self.active_url)
+        except fs.opener.errors.ParseError:
+            parseresult = None
+        if parseresult is not None and parseresult.username is not None:
+            self.authentification = "{}:{}@".format(parseresult.username,  parseresult.password)
+            self.active_url = self.active_url.replace(self.authentification, u"")
         self.browse_folder()
         self.selection_directory()
 
@@ -187,28 +195,22 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
             QtWidgets.QAbstractScrollArea.AdjustToContents)
 
         if self.selected_dir == self.active_url:
-            _sel_dir = u"."
+            _sel_dir = u""
         else:
             _sel_dir = self.selected_dir
-        # don't scan on clear
-        if not _sel_dir == u"":
+        # on clearing ui_DirList also index changes and makes an additional call of that method
+        if self.ui_DirList.count() > 0:
             try:
                 for item in sorted(self.fs.listdir(_sel_dir)):
                     _item = fs.path.combine(_sel_dir, item)
                     try:
                         if not self.fs.isdir(_item) and match_extension(item, [file_type]):
-                            try:
-                                info = self.fs.getinfo(_item, namespaces=[u'details', u'access', u'stat'])
-                            except (fs.errors.ResourceNotFound, UnicodeEncodeError):
-                                info = None
+                            info = self.get_info(_item)
                             self.file_list_items.append({_item: info})
                         elif self.fs.isdir(_item):
-                            try:
-                                info = self.fs.getinfo(_item, namespaces=[u'details', u'access', u'stat'])
-                            except (fs.errors.ResourceNotFound, UnicodeEncodeError):
-                                info = None
+                            info = self.get_info(_item)
                             self.dir_list_items.append({_item: info})
-                    except fs.errors.PermissionDenied:
+                    except (fs.errors.PermissionDenied, fs.errors.OperationFailed):
                         logging.info(u"can't access {}".format(item))
             except UnicodeDecodeError as e:
                 logging.error(u"Error: {}".format(e))
@@ -216,31 +218,10 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_FileList.setRowCount(len(self.file_list_items) + len(self.dir_list_items))
         index = 0
         for item in self.dir_list_items:
-            info = list(item.values())[0]
-            try:
-                _mod_time = info.modified.strftime(u"%Y-%m-%d %H:%M:%S")
-            except TypeError:
-                _mod_time = u""
-            _size = u"Folder"
-            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(list(item)[0]),
-                                                                     self.dir_icon, item))
-            self.ui_FileList.setCellWidget(index, 1, WidgetText(_size))
-            self.ui_FileList.setCellWidget(index, 2, WidgetText(_mod_time))
+            self.table_row(item, index, self.dir_icon, FOLDER_SPACES, folder=True)
             index = index + 1
         for item in self.file_list_items:
-            info = list(item.values())[0]
-            try:
-                _mod_time = info.modified.strftime(u"%Y-%m-%d %H:%M:%S")
-            except (AttributeError, TypeError):
-                _mod_time = u""
-            try:
-                _size = humanfriendly.format_size(info.size)
-            except (AttributeError, TypeError):
-                _size = u""
-            self.ui_FileList.setCellWidget(index, 0, WidgetImageText(fs.path.basename(list(item)[0]),
-                                                                     self.file_icon, item))
-            self.ui_FileList.setCellWidget(index, 1, WidgetText(_size))
-            self.ui_FileList.setCellWidget(index, 2, WidgetText(_mod_time))
+            self.table_row(item, index, self.file_icon, FILES_SPACES, folder=False)
             index = index + 1
         if self.last_index == 0 and not self.show_save_action:
             self.ui_FileList.clearSelection()
@@ -249,6 +230,27 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         self.ui_FileList.resizeRowsToContents()
         QtWidgets.QApplication.restoreOverrideCursor()
 
+    def table_row(self, item, index, icon, spaces, folder):
+        info = list(item.values())[0]
+        _mod_time, _size = human_readable_info(info)
+        if folder:
+            _size = u"Folder"
+        self.ui_FileList.setCellWidget(index, 0, WidgetImage(fs.path.basename(list(item)[0]),
+                                                             icon, item))
+        time.sleep(0.001)
+        _item = " " * spaces + fs.path.basename(list(item)[0])
+        self.ui_FileList.setItem(index, 0, QtWidgets.QTableWidgetItem(_item))
+        self.ui_FileList.setItem(index, 1, QtWidgets.QTableWidgetItem(_size))
+        self.ui_FileList.setItem(index, 2, QtWidgets.QTableWidgetItem(_mod_time))
+
+    def get_info(self, _item):
+        try:
+            info = self.fs.getinfo(_item, namespaces=[u'details', u'access', u'stat'])
+            time.sleep(0.001)
+        except (fs.errors.ResourceNotFound, UnicodeEncodeError):
+            info = None
+        return info
+
     @QtCore.pyqtSlot(int, int)
     def onCellClicked(self, row, column):
         """
@@ -275,7 +277,6 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         try:
             if self.wparm is not None:
                 if "folder" in self.wparm.img:
-                    _folder_names = [list(name)[0] for name in self.dir_list_items]
                     self.directory_history.append(list(self.wparm.value.keys())[0])
                     self.browse_folder(subdir=list(self.wparm.value.keys())[0])
         except AttributeError:
@@ -306,11 +307,6 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
 
         if self.fs.exists(_filename) and _filename in _file_names:
             self.ui_Action.setEnabled(True)
-            all_items = self.dir_list_items + _file_names
-            try:
-                self.ui_FileList.selectRow(all_items.index(_filename))
-            except TypeError:
-                pass
         else:
             if not self.show_save_action:
                 self.ui_Action.setEnabled(False)
@@ -450,15 +446,23 @@ def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'*.*', title=u'FS Fil
                     default_filename=default_filename, show_save_action=show_save_action)
     fp.setModal(True)
     fp.exec_()
+    active_url = fp.active_url
+    if fp.authentification is not None:
+        try:
+            parseresult = parse(fp.active_url)
+        except fs.opener.errors.ParseError:
+            parseresult = None
+        if parseresult is not None:
+            active_url = u"{}://{}{}".format(parseresult.protocol, fp.authentification, parseresult.resource)
     filename = None
     if fp.filename is not None:
         dirname = u'./'
         if fp.wparm is not None:
             dirname = fp.selected_dir
         if dirname.startswith(fp.active_url):
-            filename = u"{}{}".format(dirname, fp.filename)
+            filename = u"{}{}".format(active_url, fp.filename)
         else:
-            filename = fs.path.combine(u"{}{}".format(fp.active_url, dirname), fp.filename)
+            filename = fs.path.combine(u"{}{}".format(active_url, dirname), fp.filename)
     return filename
 
 
