@@ -25,12 +25,16 @@
 """
 import fnmatch
 import sys
+import humanfriendly
 
 from PyQt5.QtCore import pyqtProperty
 from PyQt5.QtWidgets import QWidget, QLabel, QHBoxLayout
 from PyQt5.QtCore import Qt
 from PyQt5.QtGui import QPixmap
 
+FOLDER_SPACES = 11
+FILES_SPACES = 12
+
 
 def match_extension(name, extensions=None):
     """
@@ -55,18 +59,19 @@ def root_url():
         return u"/"
 
 
-class WidgetText(QWidget):
-    def __init__(self, text, parent=None):
-        QWidget.__init__(self, parent)
-        self._text = text
-        self.setLayout(QHBoxLayout())
-        self.lbText = QLabel(self)
-        self.lbText.setAlignment(Qt.AlignRight)
-        self.layout().addWidget(self.lbText)
-        self.lbText.setText(self._text)
+def human_readable_info(info):
+    try:
+        _mod_time = info.modified.strftime(u"%Y-%m-%d %H:%M:%S")
+    except (AttributeError, TypeError):
+        _mod_time = u" "
+    try:
+        _size = humanfriendly.format_size(info.size)
+    except (AttributeError, TypeError):
+        _size = u" "
+    return _mod_time, _size
 
 
-class WidgetImageText(QWidget):
+class WidgetImage(QWidget):
     # inspired by
     # https://stackoverflow.com/questions/45896291/how-to-show-image-and-text-at-same-cell-in-qtablewidget-in-pyqt
     # slightly modified
@@ -77,23 +82,12 @@ class WidgetImageText(QWidget):
         self._value = value
         self.setLayout(QHBoxLayout())
         self.lbPixmap = QLabel(self)
-        self.lbText = QLabel(self)
         self.lbModtime = QLabel(self)
-        self.lbSize = QLabel(self)
-        self.lbModtime = QLabel(self)
-        self.lbText.setMinimumWidth(600)
-        self.lbText.setAlignment(Qt.AlignLeft)
-        self.lbSize.setMinimumWidth(200)
-        self.lbSize.setAlignment(Qt.AlignLeft)
-        self.lbModtime.setMinimumWidth(300)
-        self.lbModtime.setAlignment(Qt.AlignLeft)
         self.layout().addWidget(self.lbPixmap)
-        self.layout().addWidget(self.lbText)
         self.initUi()
 
     def initUi(self):
         self.lbPixmap.setPixmap(QPixmap(self._img).scaled(self.lbPixmap.size(), Qt.KeepAspectRatio))
-        self.lbText.setText(self._text)
 
     @pyqtProperty(str)
     def img(self):
